summary refs log tree commit diff
path: root/drivers/acpi/acpica/hwesleep.c
diff options
context:
space:
mode:
authorBob Moore <robert.moore@intel.com>2012-03-21 09:42:45 +0800
committerLen Brown <len.brown@intel.com>2012-03-22 01:45:53 -0400
commit4efeeecd884de36b77c64489dee7eb7ca4d6bed0 (patch)
treeec068d9914f1be1ec849cf1dd2e59bfaab4ae3d7 /drivers/acpi/acpica/hwesleep.c
parentdd0228e9220b6c8320ffbf64e58fdac041ec0931 (diff)
downloadlinux-4efeeecd884de36b77c64489dee7eb7ca4d6bed0.tar.gz
ACPICA: Clarify METHOD_NAME* defines for full-pathname cases
Changed the METHOD_NAME* defines that define a full pathname to
the method to METHOD_PATHNAME* in order to make it clear that
it is not a simple 4-character ACPI name. Used for the various
sleep/wake methods.

Signed-off-by: Bob Moore <robert.moore@intel.com>
Signed-off-by: Lin Ming <ming.m.lin@intel.com>
Signed-off-by: Len Brown <len.brown@intel.com>
Diffstat (limited to 'drivers/acpi/acpica/hwesleep.c')
-rw-r--r--drivers/acpi/acpica/hwesleep.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/drivers/acpi/acpica/hwesleep.c b/drivers/acpi/acpica/hwesleep.c
index 9e44c6c767e6..6cbc4e10bfa8 100644
--- a/drivers/acpi/acpica/hwesleep.c
+++ b/drivers/acpi/acpica/hwesleep.c
@@ -59,7 +59,7 @@ MODULE_PARM_DESC(bfs, "Enable evaluation of _BFS on resume".);
  *
  * FUNCTION:    acpi_hw_execute_sleep_method
  *
  * PARAMETERS:  method_name         - Pathname of method to execute
  *              integer_argument    - Argument to pass to the method
  *
  * RETURN:      None
@@ -68,7 +68,7 @@ MODULE_PARM_DESC(bfs, "Enable evaluation of _BFS on resume".);
  *              and no return value.
  *
  ******************************************************************************/
-void acpi_hw_execute_sleep_method(char *method_name, u32 integer_argument)
+void acpi_hw_execute_sleep_method(char *method_pathname, u32 integer_argument)
 {
 	struct acpi_object_list arg_list;
 	union acpi_object arg;
@@ -76,10 +76,10 @@ void acpi_hw_execute_sleep_method(char *method_name, u32 integer_argument)
 
 	ACPI_FUNCTION_TRACE(hw_execute_sleep_method);
 
-	if (!ACPI_STRCMP(METHOD_NAME__GTS, method_name) && !gts)
+	if (!ACPI_STRCMP(METHOD_PATHNAME__GTS, method_pathname) && !gts)
 		return_VOID;
 
-	if (!ACPI_STRCMP(METHOD_NAME__BFS, method_name) && !bfs)
+	if (!ACPI_STRCMP(METHOD_PATHNAME__BFS, method_pathname) && !bfs)
 		return_VOID;
 
 	/* One argument, integer_argument; No return value expected */
@@ -89,10 +89,10 @@ void acpi_hw_execute_sleep_method(char *method_name, u32 integer_argument)
 	arg.type = ACPI_TYPE_INTEGER;
 	arg.integer.value = (u64)integer_argument;
 
-	status = acpi_evaluate_object(NULL, method_name, &arg_list, NULL);
+	status = acpi_evaluate_object(NULL, method_pathname, &arg_list, NULL);
 	if (ACPI_FAILURE(status) && status != AE_NOT_FOUND) {
 		ACPI_EXCEPTION((AE_INFO, status, "While executing method %s",
-				method_name));
+				method_pathname));
 	}
 
 	return_VOID;
@@ -138,7 +138,7 @@ acpi_status acpi_hw_extended_sleep(u8 sleep_state)
 
 	/* Execute the _GTS method (Going To Sleep) */
 
-	acpi_hw_execute_sleep_method(METHOD_NAME__GTS, sleep_state);
+	acpi_hw_execute_sleep_method(METHOD_PATHNAME__GTS, sleep_state);
 
 	/* Flush caches, as per ACPI specification */
 
@@ -208,7 +208,7 @@ acpi_status acpi_hw_extended_wake_prep(u8 sleep_state)
 				 &acpi_gbl_FADT.sleep_control);
 	}
 
-	acpi_hw_execute_sleep_method(METHOD_NAME__BFS, sleep_state);
+	acpi_hw_execute_sleep_method(METHOD_PATHNAME__BFS, sleep_state);
 	return_ACPI_STATUS(AE_OK);
 }
 
@@ -235,8 +235,8 @@ acpi_status acpi_hw_extended_wake(u8 sleep_state)
 
 	/* Execute the wake methods */
 
-	acpi_hw_execute_sleep_method(METHOD_NAME__SST, ACPI_SST_WAKING);
-	acpi_hw_execute_sleep_method(METHOD_NAME__WAK, sleep_state);
+	acpi_hw_execute_sleep_method(METHOD_PATHNAME__SST, ACPI_SST_WAKING);
+	acpi_hw_execute_sleep_method(METHOD_PATHNAME__WAK, sleep_state);
 
 	/*
 	 * Some BIOS code assumes that WAK_STS will be cleared on resume
@@ -246,6 +246,6 @@ acpi_status acpi_hw_extended_wake(u8 sleep_state)
 	(void)acpi_write(ACPI_X_WAKE_STATUS, &acpi_gbl_FADT.sleep_status);
 	acpi_gbl_system_awake_and_running = TRUE;
 
-	acpi_hw_execute_sleep_method(METHOD_NAME__SST, ACPI_SST_WORKING);
+	acpi_hw_execute_sleep_method(METHOD_PATHNAME__SST, ACPI_SST_WORKING);
 	return_ACPI_STATUS(AE_OK);
 }
@@ -59,7 +59,7 @@ MODULE_PARM_DESC(bfs, "Enable evaluation of _BFS on resume".);
  * FUNCTION:    acpi_hw_execute_sleep_method
  *
- * PARAMETERS:  method_name         - Pathname of method to execute
+ * PARAMETERS:  method_pathname     - Pathname of method to execute
  *              integer_argument    - Argument to pass to the method
  *